@@ -5,12 +5,12 @@ package Data::Scan::Printer;
 
 # ABSTRACT: Data::Scan::Printer - Example of a printer consumer for Data::Scan
 
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 # AUTHORITY
 
 use Exporter qw/import/;
-use vars qw/@EXPORT/;
+use vars qw/@EXPORT %Option/;
 use Data::Scan::Impl::Printer;
 use Moo;
 extends 'Data::Scan';
@@ -18,15 +18,19 @@ extends 'Data::Scan';
 # Using this module intentionaly means caller is ok to pollute its namespace
 #
 @EXPORT = qw/dspp/;
+#
+# User is advised to localized that
+#
+%Option = ();
 
 
 sub dspp {
-  my $consumer = Data::Scan::Impl::Printer->new(%Data::Scan::Printer::Option);
+  my $consumer = Data::Scan::Impl::Printer->new(%Option);
   __PACKAGE__->new(consumer => $consumer)->process(@_);
   #
-  # We know this consumer has a dsoutput method
+  # We know this consumer has a dsprint method
   #
-  print $consumer->dsoutput
+  $consumer->dsprint
 }
 
 
@@ -44,7 +48,7 @@ Data::Scan::Printer - Data::Scan::Printer - Example of a printer consumer for Da
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -52,7 +56,8 @@ version 0.003
     use warnings FATAL => 'all';
     use Data::Scan::Printer;
 
-    my $this = bless([ 'var1', 'var2', {'a' => 'b', 'c' => 'd'}, \undef, \\undef, [] ], 'TEST');
+    my $this = bless([ 'var1', 'var2', {'a' => 'b', 'c' => 'd'}, \undef, \\undef, [], sub { return 'something' } ], 'TEST');
+    local %Data::Scan::Printer::Option = (with_deparse => 1);
     dspp($this);
 
 =head1 DESCRIPTION
@@ -63,11 +68,11 @@ Data::Scan::Printer is polluting user's namespace with a dspp() method, showing
 
 =head2 dspp(@arguments)
 
-Print to STDOUT a dumped vision of the arguments.
+Print to Data::Scan::Impl::Printer's handle a dumped vision of @arguments. An instance of Data::Scan::Impl::Printer is created automatically, using parameters that have to be available in %Data::Scan::Printer::Option. Please refer to L<Data::Scan::Impl::Printer> documentation for the available options.
 
 =head1 SEE ALSO
 
-L<Data::Printer>
+L<Data::Scan>, L<Data::Scan::Impl::Printer>
 
 =head1 AUTHOR
 
